We provide demo guides for multiple use-cases, each one involving several AEAs interacting in a different scenario.

These demos serve to highlight the concept of AEAs as well as provide inspiration for developers. Demos should not be taken as production ready software, although every care is taken to fix bugs when reported.

Demos are alphabetically sorted, we recommend you start with the <a href="../weather-skills">weather skills demo</a>.